==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24RolloverButtonBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$RolloverButtonBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c174c13db1219998 javax_swing_plaf_basic_BasicBorders__24ButtonBorder
// @dep_class 394d7b8ac097349 javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicBorders__24ButtonBorder

#include "javax/swing/plaf/basic/BasicBorders__24ButtonBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods {
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24RolloverButtonBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$RolloverButtonBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c174c13db1219998 javax_swing_plaf_basic_BasicBorders__24ButtonBorder
// @dep_class 394d7b8ac097349 javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicBorders__24ButtonBorder

#include "javax/swing/plaf/basic/BasicBorders__24ButtonBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods {
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24RolloverButtonBorder_H_ */
